"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.bootstrapShell = void 0;
const shell_registry_1 = require("./shell.registry");
const readline = require('readline');
async function bootstrapShell(options = { prompt: '⤳' }) {
    const rl = readline.createInterface({
        input: process.stdin,
        output: process.stdout,
        prompt: `${options.prompt} `,
    });
    const print = options.shellPrinter || ((value) => console.log(value));
    const messages = Object.assign({ notFound: `Say what? I might have heard $input`, wrongUsage: `Wrong usage: $command $pattern` }, options.messages);
    const onLine = async (line) => {
        const splittedLineResult = line.trim().split(' ');
        const command = shell_registry_1.ShellRegistry.findCommand(splittedLineResult[0]);
        if (!command) {
            print(messages.notFound.replace('$input', line));
            return;
        }
        const commandArguments = splittedLineResult.slice(1);
        return command.handler(commandArguments, { wrongUsage: messages.wrongUsage }, print);
    };
    rl.on('line', async (input) => onLine(input).then(() => rl.prompt())).on('close', () => process.exit());
}
exports.bootstrapShell = bootstrapShell;
//# sourceMappingURL=shell.bootstraper.js.map