"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShellRegistry = void 0;
const helper_1 = require("./helper");
let ShellRegistry = (() => {
    class ShellRegistry {
        constructor() { }
        static registerComponent(component) {
            this.ensureComponentIsTruthy(component);
            const componentClassName = component.constructor.name;
            this.components = Object.assign(Object.assign({}, this.components), { [componentClassName]: component });
        }
        static ensureComponentIsTruthy(component) {
            if (!component) {
                throw new Error(`Component you're trying to register has falsy value (probably null or undefined)`);
            }
        }
        static getComponent(componentClassName) {
            return this.components[componentClassName];
        }
        static registerCommand(command) {
            this.ensureCommandIsTruthy(command);
            const prefixedCommand = command.prefix + command.name;
            this.commands = Object.assign(Object.assign({}, this.commands), { [prefixedCommand]: command });
        }
        static ensureCommandIsTruthy(command) {
            if (!command || (command && !command.name)) {
                throw new Error(`Cannot register command because its value or name is falsy (it may be empty command name in @ShellCommand decorator)`);
            }
        }
        static findCommand(commandWithPrefix) {
            return this.commands[commandWithPrefix];
        }
        static getImmutableComponents() {
            return Object.keys(helper_1.deepClone(this.components));
        }
        static getImmutableCommands() {
            return this.convertCommandsToArray(helper_1.deepClone(this.commands));
        }
        static convertCommandsToArray(commandsInObject) {
            return Object.entries(commandsInObject).map((entry) => (Object.assign(Object.assign({}, entry[1]), { name: entry[0] })));
        }
    }
    ShellRegistry.components = {};
    ShellRegistry.commands = {};
    return ShellRegistry;
})();
exports.ShellRegistry = ShellRegistry;
//# sourceMappingURL=shell.registry.js.map